@@ -254,7 +254,7 @@ func KillContainer(w http.ResponseWriter, r *http.Request) {
 			utils.InternalServerError(w, err)
 			return
 		}
-		if sig == 0 || syscall.Signal(sig) == syscall.SIGKILL {
+		if sig == 0 || sig == syscall.SIGKILL {
 			opts := entities.WaitOptions{
 				Condition: []define.ContainerStatus{define.ContainerStateExited, define.ContainerStateStopped},
 				Interval:  time.Millisecond * 250,
@@ -341,8 +341,8 @@ func LibpodToContainer(l *libpod.Container, sz bool) (*handlers.Container, error
 	for idx, portMapping := range portMappings {
 		ports[idx] = types.Port{
 			IP:          portMapping.HostIP,
-			PrivatePort: uint16(portMapping.ContainerPort),
-			PublicPort:  uint16(portMapping.HostPort),
+			PrivatePort: portMapping.ContainerPort,
+			PublicPort:  portMapping.HostPort,
 			Type:        portMapping.Protocol,
 		}
 	}
@@ -369,26 +369,28 @@ func LibpodToContainer(l *libpod.Container, sz bool) (*handlers.Container, error
 		return nil, err
 	}
 
-	return &handlers.Container{Container: types.Container{
-		ID:         l.ID(),
-		Names:      []string{fmt.Sprintf("/%s", l.Name())},
-		Image:      imageName,
-		ImageID:    "sha256:" + imageID,
-		Command:    strings.Join(l.Command(), " "),
-		Created:    l.CreatedTime().Unix(),
-		Ports:      ports,
-		SizeRw:     sizeRW,
-		SizeRootFs: sizeRootFs,
-		Labels:     l.Labels(),
-		State:      stateStr,
-		Status:     status,
-		HostConfig: struct {
-			NetworkMode string `json:",omitempty"`
-		}{
-			"host"},
-		NetworkSettings: &networkSettings,
-		Mounts:          mounts,
-	},
+	return &handlers.Container{
+		Container: types.Container{
+			ID:         l.ID(),
+			Names:      []string{fmt.Sprintf("/%s", l.Name())},
+			Image:      imageName,
+			ImageID:    "sha256:" + imageID,
+			Command:    strings.Join(l.Command(), " "),
+			Created:    l.CreatedTime().Unix(),
+			Ports:      ports,
+			SizeRw:     sizeRW,
+			SizeRootFs: sizeRootFs,
+			Labels:     l.Labels(),
+			State:      stateStr,
+			Status:     status,
+			HostConfig: struct {
+				NetworkMode string `json:",omitempty"`
+			}{
+				"host",
+			},
+			NetworkSettings: &networkSettings,
+			Mounts:          mounts,
+		},
 		ContainerCreateConfig: types.ContainerCreateConfig{},
 	}, nil
 }
